Summary: Kafka is a distributed publish/subscribe messaging system
Name: kafka
Version: 0.8.2.1
Release: 1%{?dist}
Group: Applications/Internet
License: Apache (v2)
Source0: kafka-%{version}.tgz
Source1: kafka.service
Source2: zookeeper.service
Source3: kafka
Source4: zookeeper
Source5: kafka-nofiles.conf
URL: http://kafka.apache.org
BuildRoot: %{_tmppath}/%{name}-root
Distribution: Jeff Geiger
Vendor: BroEZ
Packager: Jeff Geiger <jeff@broez.com>

Requires: java >= 1.6
Requires(pre): shadow-utils
#Requires: zookeeper >= 3.3.4

%description
It is designed to support the following

Persistent messaging with O(1) disk structures that provide constant time performance even with many TB of stored messages.
High-throughput: even with very modest hardware Kafka can support hundreds of thousands of messages per second.
Explicit support for partitioning messages over Kafka servers and distributing consumption over a cluster of consumer machines while maintaining per-partition ordering semantics.
Support for parallel data load into Hadoop.
Kafka is aimed at providing a publish-subscribe solution that can handle all activity stream data and processing on a consumer-scale web site. This kind of activity (page views, searches, and other user actions) are a key ingredient in many of the social feature on the modern web. This data is typically handled by "logging" and ad hoc log aggregation solutions due to the throughput requirements. This kind of ad hoc solution is a viable solution to providing logging data to an offline analysis system like Hadoop, but is very limiting for building real-time processing. Kafka aims to unify offline and online processing by providing a mechanism for parallel load into Hadoop as well as the ability to partition real-time consumption over a cluster of machines.

See our web site for more details on the project. (http://kafka.apache.org/)

%pre

# Create user and group
getent group kafka >/dev/null || groupadd -r kafka
getent passwd kafka >/dev/null || \
    useradd -r -g kafka -d /opt/kafka -s /bin/bash \
    -c "Kafka System Account" kafka
getent group zookeeper >/dev/null || groupadd -r zookeeper
getent passwd zookeeper >/dev/null || \
    useradd -r -g zookeeper -G kafka -d /opt/kafka -s /bin/bash \
    -c "Zookeeper System Account" zookeeper
#Create logs directory
mkdir -p /opt/kafka/logs
chown kafka:kafka /opt/kafka/logs
chmod 775 /opt/kafka/logs

exit 0

%post
alternatives --install /opt/kafka kafkahome  /opt/%{name} 1

%preun
service kafka stop

%postun
alternatives --remove kafkahome  /opt/%{name}

%prep

%setup

#%patch0 -p1
#%patch1 -p1

%build
# Build package

#gradle downloadWrapper
#./gradlew -PscalaVersion=2.10.4 releaseTarGz

%install

# Clean out any previous builds not on slash
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__mkdir_p} %{buildroot}/opt/%{name}
%{__cp} -R * %{buildroot}/opt/%{name}
%{__mkdir_p} %{buildroot}/var/log/kafka
#%{__mkdir_p} %{buildroot}/etc/rc.d/init.d
#install -m 755 %{S:1} %{buildroot}/etc/rc.d/init.d/kafka

# Simply create this oneliner in the spec file
%{__mkdir_p} %{buildroot}/etc/profile.d/
echo 'export PATH=${PATH}:/opt/kafka/bin' > %{buildroot}/etc/profile.d/kafka.sh

# systemd service file
mkdir -p ${RPM_BUILD_ROOT}/etc/systemd/system
install -m0644 %{SOURCE1} ${RPM_BUILD_ROOT}/etc/systemd/system/kafka.service
install -m0644 %{SOURCE2} ${RPM_BUILD_ROOT}/etc/systemd/system/zookeeper.service

# sysconfig files
mkdir -p ${RPM_BUILD_ROOT}/etc/sysconfig
install -m0644 %{SOURCE3} ${RPM_BUILD_ROOT}/etc/sysconfig/kafka
install -m0644 %{SOURCE4} ${RPM_BUILD_ROOT}/etc/sysconfig/zookeeper

# limits files
mkdir -p ${RPM_BUILD_ROOT}/etc/security/limits.d
install -m0644 %{SOURCE5} ${RPM_BUILD_ROOT}/etc/security/limits.d/kafka-nofiles.conf

%files
%defattr(-,kafka,kafka)

%config /opt/%{name}/config
/opt/%{name}
/var/log/kafka
#/etc/rc.d/init.d/kafka
/etc/profile.d/kafka.sh
/etc/systemd/system/kafka.service
/etc/systemd/system/zookeeper.service
/etc/sysconfig/kafka
/etc/sysconfig/zookeeper
/etc/security/limits.d/kafka-nofiles.conf

%clean
#used to cleanup things outside the build area and possibly inside.
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%changelog
* Fri Jul 24 2015 Jeff Geiger <jeff@broez.com>
- Modified for systemd and to use the precompiled binaries from Apache
* Mon Sep 16 2013 Niels Basjes <kafka@basjes.nl>
- Refactoring the scripting
* Fri Mar 15 2013 Mark Poole <mpoole@apache.org>
- First build
